==> haskell-test-framework-smallcheck-0.2-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-9cJmV1VNDwqCgt3UkD9mHA
key:                  test-framework-smallcheck-0.2-9cJmV1VNDwqCgt3UkD9mHA
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  c2a5fac75175c987da53a7c80ae4f484
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-9cJmV1VNDwqCgt3UkD9mHA
depends:
    base-4.16.4.0 smallcheck-1.2.1.1-L343DgkQeknLndheyubkP1
    test-framework-0.8.2.0-CeElrYrpXbP8xqd4AFjJtr transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-264-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-Bh5C7scqwas6AHyUC7xu5d
key:                  test-framework-smallcheck-0.2-Bh5C7scqwas6AHyUC7xu5d
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  48128b3ced28c81a9a2b79545e5ec457
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-Bh5C7scqwas6AHyUC7xu5d
depends:
    base-4.16.4.0 smallcheck-1.2.1.1-GC6Yc8e24LDKe59BCqx4To
    test-framework-0.8.2.0-9OFwjLKZeUZCNJY1fhpiPu transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
